@@ -2,43 +2,43 @@
 <context>
     <name>CanvasGridView</name>
     <message>
-        <location filename="../view/canvasgridview.cpp" line="3451"/>
+        <location filename="../view/canvasgridview.cpp" line="3474"/>
         <source>Icon size</source>
         <translation>Nişan ölçüsü</translation>
     </message>
     <message>
-        <location filename="../view/canvasgridview.cpp" line="3460"/>
+        <location filename="../view/canvasgridview.cpp" line="3483"/>
         <source>Auto merge</source>
         <translation>Avtomatik birləşdirmə</translation>
     </message>
     <message>
-        <location filename="../view/canvasgridview.cpp" line="3472"/>
+        <location filename="../view/canvasgridview.cpp" line="3495"/>
         <source>Auto arrange</source>
         <translation>Avtomatik tənzimləmə</translation>
     </message>
     <message>
-        <location filename="../view/canvasgridview.cpp" line="3511"/>
+        <location filename="../view/canvasgridview.cpp" line="3534"/>
         <source>Corner Settings</source>
         <translation>Künc ayarları</translation>
     </message>
     <message>
-        <location filename="../view/canvasgridview.cpp" line="3520"/>
-        <location filename="../view/canvasgridview.cpp" line="3525"/>
+        <location filename="../view/canvasgridview.cpp" line="3543"/>
+        <location filename="../view/canvasgridview.cpp" line="3548"/>
         <source>Set Wallpaper</source>
         <translation>Divar kağızını təyin etmək</translation>
     </message>
     <message>
-        <location filename="../view/canvasgridview.cpp" line="3523"/>
+        <location filename="../view/canvasgridview.cpp" line="3546"/>
         <source>Wallpaper and Screensaver</source>
         <translation>Divar kağızı və Ekran şəkli</translation>
     </message>
     <message>
-        <location filename="../view/canvasgridview.cpp" line="3706"/>
+        <location filename="../view/canvasgridview.cpp" line="3732"/>
         <source>Properties</source>
         <translation>Tərcihlər</translation>
     </message>
     <message>
-        <location filename="../view/canvasgridview.cpp" line="3501"/>
+        <location filename="../view/canvasgridview.cpp" line="3524"/>
         <source>Display Settings</source>
         <translation>Ekran ayarları</translation>
     </message>
@@ -46,27 +46,27 @@
 <context>
     <name>DesktopItemDelegate</name>
     <message>
-        <location filename="../view/desktopitemdelegate.cpp" line="40"/>
+        <location filename="../view/desktopitemdelegate.cpp" line="23"/>
         <source>Tiny</source>
         <translation>İncə</translation>
     </message>
     <message>
-        <location filename="../view/desktopitemdelegate.cpp" line="41"/>
+        <location filename="../view/desktopitemdelegate.cpp" line="24"/>
         <source>Small</source>
         <translation>Kiçik</translation>
     </message>
     <message>
-        <location filename="../view/desktopitemdelegate.cpp" line="42"/>
+        <location filename="../view/desktopitemdelegate.cpp" line="25"/>
         <source>Medium</source>
         <translation>Orta</translation>
     </message>
     <message>
-        <location filename="../view/desktopitemdelegate.cpp" line="43"/>
+        <location filename="../view/desktopitemdelegate.cpp" line="26"/>
         <source>Large</source>
         <translation>Geniş</translation>
     </message>
     <message>
-        <location filename="../view/desktopitemdelegate.cpp" line="44"/>
+        <location filename="../view/desktopitemdelegate.cpp" line="27"/>
         <source>Super large</source>
         <translation>Çox geniş</translation>
     </message>
@@ -74,7 +74,7 @@
 <context>
     <name>DesktopMain</name>
     <message>
-        <location filename="../main.cpp" line="169"/>
+        <location filename="../main.cpp" line="158"/>
         <source>Desktop</source>
         <translation>İş Masası</translation>
     </message>
@@ -82,74 +82,80 @@
 <context>
     <name>Frame</name>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="727"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="700"/>
         <source>Wallpaper Slideshow</source>
         <translation>Divar kağızları slaydı</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="773"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="746"/>
         <source>When login</source>
         <translation>Daxil oduqda</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="775"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="748"/>
         <source>When wakeup</source>
         <translation>Oyandıqda</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="827"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="800"/>
         <source>Require a password on wakeup</source>
         <translation>Oyatmaq üçün şifrə tələb olunur</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="859"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="832"/>
         <source>Never</source>
         <translation>Heç vaxt</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="861"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="834"/>
         <source>Wait:</source>
         <translation>Gözləmək:</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="894"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="867"/>
         <source>Wallpaper</source>
         <translation>Divar kağızı</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="906"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="879"/>
         <source>Screensaver</source>
         <translation>Ekran şəkli</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="971"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="944"/>
         <source>Loading wallpapers...</source>
         <translation>Divar kağızları yüklənir...</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="973"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="946"/>
         <source>Loading screensavers...</source>
         <translation>Ekran şəkilləri yüklənir</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1031"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1004"/>
         <source>Desktop</source>
         <comment>button</comment>
         <translation>İş Masası</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1032"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1005"/>
         <source>Lock Screen</source>
         <comment>button</comment>
         <translation>Kilid ekranı</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1033"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1006"/>
         <source>Both</source>
         <translation>Hər ikisi</translation>
     </message>
     <message>
-        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1108"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1094"/>
+        <source>Custom Screensaver</source>
+        <translation>Fərdi ekran qoruyucusu</translation>
+    </message>
+    <message>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1095"/>
+        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1097"/>
         <source>Apply</source>
         <comment>button</comment>
         <translation>Tətbiq etmək</translation>
@@ -158,14 +164,14 @@
 <context>
     <name>WaterMaskFrame</name>
     <message>
-        <location filename="../view/watermaskframe.cpp" line="394"/>
-        <location filename="../view/watermaskframe.cpp" line="395"/>
+        <location filename="../view/watermaskframe.cpp" line="127"/>
+        <location filename="../view/watermaskframe.cpp" line="128"/>
         <source>Not authorized</source>
         <translation>Səlahiyyət verilməyib</translation>
     </message>
     <message>
-        <location filename="../view/watermaskframe.cpp" line="405"/>
-        <location filename="../view/watermaskframe.cpp" line="406"/>
+        <location filename="../view/watermaskframe.cpp" line="136"/>
+        <location filename="../view/watermaskframe.cpp" line="137"/>
         <source>In trial period</source>
         <translation>Sınaq müddətində</translation>
     </message>
