@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     yanghao<yanghao@uniontech.com>
- *
- * Maintainer: zhengyouge<zhengyouge@uniontech.com>
- *             yanghao<yanghao@uniontech.com>
- *             hujianzhong<hujianzhong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "bookmarkmanager.h"
 #include "dfileservices.h"
@@ -400,6 +381,10 @@ void BookMarkManager::update(const QVariant &value)
     // 清空缓存中已不存在的书签
     for (const DUrl &url : bookmarkUrlList) {
         const BookmarkData data = m_bookmarkDataMap.value(url);
+        // #bug154317, the second reason that the desktop to show bookmarks
+        //  item on right-click menu is because there is no sync clearing.
+        // (Based on product requirements, bookmarks are not displayed in the right menu of the desktop).
+        m_bookmarkDataMap.remove(url);
         m_bookmarks[url] = nullptr;
         DAbstractFileWatcher::ghostSignal(DUrl(BOOKMARK_ROOT), &DAbstractFileWatcher::fileDeleted, data.m_url);
     }
