@@ -1,24 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     gongheng<gongheng@uniontech.com>
- *
- * Maintainer: zhengyouge<zhengyouge@uniontech.com>
- *             gongheng<gongheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "computerpropertydialog.h"
 #include "ddiskmanager.h"
@@ -77,6 +59,45 @@ static QString formatCap(qulonglong cap, const int size = 1024, quint8 precision
     return "";
 }
 
+static QString editionInfo()
+{
+    QString edition {""};
+    // 专业版
+    if (DSysInfo::UosEdition::UosProfessional == DSysInfo::uosEditionType()) {
+        // 是否激活
+        QDBusInterface deepinLicenseInfo("com.deepin.license",
+                                         "/com/deepin/license/Info",
+                                         "com.deepin.license.Info",
+                                         QDBusConnection::systemBus());
+        deepinLicenseInfo.setTimeout(1000);
+        if (!deepinLicenseInfo.isValid()) {
+            qWarning() << "Dbus com.deepin.license is not valid";
+            return "";
+        }
+        qInfo() << "Start call Dbus com.deepin.license AuthorizationState";
+        int activeInfo = deepinLicenseInfo.property("AuthorizationState").toInt();
+        qInfo() << "End call Dbus com.deepin.license AuthorizationState";
+        if (activeInfo == 1) {
+            // 政务授权、企业授权、原始授权
+            qInfo() << "Start call Dbus com.deepin.license AuthorizationProperty";
+            uint authorizedInfo = deepinLicenseInfo.property("AuthorizationProperty").toUInt();
+            qInfo() << "End call Dbus com.deepin.license AuthorizationProperty";
+            if (authorizedInfo == 1) {
+                edition = DSysInfo::uosEditionName() + "(" + QObject::tr("For Government") + ")" + "(" + DSysInfo::minorVersion() + ")";
+            } else if (authorizedInfo == 2) {
+                edition = DSysInfo::uosEditionName() + "(" + QObject::tr("For Enterprise") + ")" + "(" + DSysInfo::minorVersion() + ")";
+            } else {
+                edition = DSysInfo::uosEditionName() + "(" + DSysInfo::minorVersion() + ")";
+            }
+        } else {
+            edition = DSysInfo::uosEditionName() + "(" + DSysInfo::minorVersion() + ")";
+        }
+    } else {
+        edition = DSysInfo::uosEditionName() + "(" + DSysInfo::minorVersion() + ")";
+    }
+    return edition;
+}
+
 GetInfoWork::GetInfoWork(QObject *parent)
     : QThread(parent)
 {
@@ -173,30 +194,9 @@ void GetInfoWork::run()
                 if (DSysInfo::UosType::UosServer == DSysInfo::uosType()) {  // 服务器版本
                     Edition = DSysInfo::minorVersion() + DSysInfo::uosEditionName();
                 } else {
-                    // 专业版
-                    if (DSysInfo::UosEdition::UosProfessional == DSysInfo::uosEditionType()) {
-                        // 是否激活
-                        QDBusInterface deepinLicenseInfo("com.deepin.license",
-                                                         "/com/deepin/license/Info",
-                                                         "com.deepin.license.Info",
-                                                         QDBusConnection::systemBus());
-                       int activeInfo = deepinLicenseInfo.property("AuthorizationState").toInt();
-                       if (activeInfo == 1) {
-                           // 政务授权、企业授权、原始授权
-                           uint authorizedInfo = deepinLicenseInfo.property("AuthorizationProperty").toUInt();
-                           if (authorizedInfo == 1) {
-                               Edition = DSysInfo::uosEditionName() + "(" + tr("For Government") + ")" + "(" + DSysInfo::minorVersion() + ")";
-                           } else if (authorizedInfo == 2) {
-                               Edition = DSysInfo::uosEditionName() + "(" + tr("For Enterprise") + ")" + "(" + DSysInfo::minorVersion() + ")";
-                           } else {
-                               Edition = DSysInfo::uosEditionName() + "(" + DSysInfo::minorVersion() + ")";
-                           }
-                       } else {
-                           Edition = DSysInfo::uosEditionName() + "(" + DSysInfo::minorVersion() + ")";
-                       }
-                    } else {
-                        Edition = DSysInfo::uosEditionName() + "(" + DSysInfo::minorVersion() + ")";
-                    }
+                    Edition = editionInfo();
+                    if (Edition.isEmpty())
+                        qWarning() << "get edition info failed";
                 }
             }
             // 获取系统版本号
@@ -486,30 +486,9 @@ QHash<QString, QString> ComputerPropertyDialog::getMessage(const QStringList &da
         if (DSysInfo::UosType::UosServer == DSysInfo::uosType()) {  // 服务器版本
             Edition = DSysInfo::minorVersion() + DSysInfo::uosEditionName();
         } else {
-            // 专业版
-            if (DSysInfo::UosEdition::UosProfessional == DSysInfo::uosEditionType()) {
-                // 是否激活
-                QDBusInterface deepinLicenseInfo("com.deepin.license",
-                                                 "/com/deepin/license/Info",
-                                                 "com.deepin.license.Info",
-                                                 QDBusConnection::systemBus());
-               int activeInfo = deepinLicenseInfo.property("AuthorizationState").toInt();
-               if (activeInfo == 1) {
-                   // 政务授权、企业授权、原始授权
-                   uint authorizedInfo = deepinLicenseInfo.property("AuthorizationProperty").toUInt();
-                   if (authorizedInfo == 1) {
-                       Edition = DSysInfo::uosEditionName() + "(" + tr("For Government") + ")" + "(" + DSysInfo::minorVersion() + ")";
-                   } else if (authorizedInfo == 2) {
-                       Edition = DSysInfo::uosEditionName() + "(" + tr("For Enterprise") + ")" + "(" + DSysInfo::minorVersion() + ")";
-                   } else {
-                       Edition = DSysInfo::uosEditionName() + "(" + DSysInfo::minorVersion() + ")";
-                   }
-               } else {
-                   Edition = DSysInfo::uosEditionName() + "(" + DSysInfo::minorVersion() + ")";
-               }
-            } else {
-                Edition = DSysInfo::uosEditionName() + "(" + DSysInfo::minorVersion() + ")";
-            }
+            Edition = editionInfo();
+            if (Edition.isEmpty())
+                qWarning() << "get edition info failed";
         }
         //! 获取系统版本号
         version = DSysInfo::majorVersion();
