@@ -1,24 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     gongheng<gongheng@uniontech.com>
- *
- * Maintainer: zhengyouge<zhengyouge@uniontech.com>
- *             gongheng<gongheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "shareinfoframe.h"
 #include "propertydialog.h"
@@ -102,7 +84,10 @@ void ShareInfoFrame::initUI()
     SectionKeyLabel *permissionLabel = new SectionKeyLabel(tr("Permission"));
     permissionLabel->setFixedWidth(labelWidth);
     m_permissoComBox = new QComboBox(this);
-    m_permissoComBox->view()->parentWidget()->setAttribute(Qt::WA_TranslucentBackground);
+    QPalette peMenuBg;
+    QColor color = palette().color(QPalette::ColorGroup::Active, QPalette::ColorRole::Window);
+    peMenuBg.setColor(QPalette::Window, color);
+    m_permissoComBox->setPalette(peMenuBg);
     m_permissoComBox->setFixedWidth(fieldWidth);
     QStringList permissions;
     permissions << tr("Read and write") << tr("Read only");
@@ -111,7 +96,7 @@ void ShareInfoFrame::initUI()
     SectionKeyLabel *anonymityLabel = new SectionKeyLabel(tr("Anonymous"));
     anonymityLabel->setFixedWidth(labelWidth);
     m_anonymityCombox = new QComboBox(this);
-    m_anonymityCombox->view()->parentWidget()->setAttribute(Qt::WA_TranslucentBackground);
+    m_anonymityCombox->setPalette(peMenuBg);
     m_anonymityCombox->setFixedWidth(fieldWidth);
     QStringList anonymityChoices;
     anonymityChoices << tr("Not allow") << tr("Allow");
@@ -452,19 +437,19 @@ bool ShareInfoFrame::doShareInfoSetting()
     //该权限修改逻辑只针对普通用户共享自己的文件时有效
     //root用户共享的行为不主动修改目录权限，既共享时不修改/root的其他执行权限和普通用户主目录的其他执行权限
     if (ret && m_anonymityCombox->currentIndex() != 0 && getuid() != 0) {
-        DUrl userUrl = DUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::HomeLocation));//userUrl allways = file:///home/username
-        if(m_fileinfo->path().contains(userUrl.path())){
-            if (!m_fileinfo->path().startsWith(userUrl.path())) {//for example: m_fileinfo->path() = /data/home/username/somefolder
-                QString prefix = m_fileinfo->path().section(userUrl.path(),0,0);
-                QString newPath = prefix + userUrl.path();
-                userUrl.setPath(newPath);
-            }
-            DAbstractFileInfoPointer userFileInfo = fileService->createFileInfo(this, userUrl);
-            if (userFileInfo && userFileInfo->exists()
-                    && (userFileInfo->permissions() & QFileDevice::ExeOther) != QFileDevice::ExeOther)
-                fileService->setPermissions(this, userUrl, userFileInfo->permissions() | QFileDevice::ExeOther);
-        }
-    }
+         DUrl userUrl = DUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::HomeLocation));//userUrl allways = file:///home/username
+         if(m_fileinfo->path().contains(userUrl.path())){
+             if (!m_fileinfo->path().startsWith(userUrl.path())) {//for example: m_fileinfo->path() = /data/home/username/somefolder
+                 QString prefix = m_fileinfo->path().section(userUrl.path(),0,0);//pick "/data"
+                 QString newPath = prefix + userUrl.path();//remove "/somefolder" => "/data/home/username"
+                 userUrl.setPath(newPath);
+             }
+             DAbstractFileInfoPointer userFileInfo = fileService->createFileInfo(this, userUrl);
+             if (userFileInfo && userFileInfo->exists()
+                     && (userFileInfo->permissions() & QFileDevice::ExeOther) != QFileDevice::ExeOther)
+                 fileService->setPermissions(this, userUrl, userFileInfo->permissions() | QFileDevice::ExeOther);
+         }
+     }
 
     return ret;
 }
