@@ -1,27 +1,11 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     xushitong<xushitong@uniontech.com>
- *
- * Maintainer: dengkeyun<dengkeyun@uniontech.com>
- *             max-lv<lvwujun@uniontech.com>
- *             zhangsheng<zhangsheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "mountaskpassworddialog.h"
+#include "shutil/smbintegrationswitcher.h"
+#include "../app/define.h"
+
 #include <QVBoxLayout>
 #include <QFormLayout>
 #include <QDebug>
@@ -139,6 +123,9 @@ void MountAskPasswordDialog::initUI()
     addButtons(buttonTexts);
     setSpacing(10);
     setDefaultButton(1);
+    QTimer::singleShot(0,this,[this](){
+        this->moveToCenter(); // 因networkmanager.cpp中while循环中局部事件循环的存在，导致对话框不能移到中央，这里采用QTimer触发
+    });
 }
 
 void MountAskPasswordDialog::initConnect()
