@@ -1,26 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2018 Deepin Technology Co., Ltd.
- *               2016 ~ 2018 dragondjf
- *
- * Author:     dragondjf<dingjiangfeng@deepin.com>
- *
- * Maintainer: dragondjf<dingjiangfeng@deepin.com>
- *             zccrs<zhangjide@deepin.com>
- *             Tangtong<tangtong@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "dfilemenumanager.h"
 #include "dfmglobal.h"
@@ -41,6 +21,7 @@
 #include "shutil/fileutils.h"
 #include "shutil/mimesappsmanager.h"
 #include "shutil/danythingmonitorfilter.h"
+#include "shutil/smbintegrationswitcher.h"
 #include "controllers/pathmanager.h"
 #include "plugins/pluginmanager.h"
 #include "dde-file-manager-plugins/plugininterfaces/menu/menuinterface.h"
@@ -68,11 +49,11 @@
 #include "extensionimpl/dfmextmendefine.h"
 #include "extensionimpl/private/dfmextmenuimpl_p.h"
 #include "utils/grouppolicy.h"
+#include "rlog/rlog.h"
 
 #include <dgiomount.h>
 #include <dgiofile.h>
 #include <dgiovolumemanager.h>
-
 #include <DSysInfo>
 
 #include <QMetaObject>
@@ -87,6 +68,7 @@
 #include <QDebug>
 #include <QPushButton>
 #include <QWidgetAction>
+#include <QApplication>
 
 #include <dgiosettings.h>
 #include <unistd.h>
@@ -192,6 +174,11 @@ DFileMenu *DFileMenuManager::createToolBarSettingsMenu(const QSet<MenuAction> &d
                << MenuAction::SetUserSharePassword
                << MenuAction::Settings;
 
+    QSettings settings("/etc/deepin-installer.conf", QSettings::IniFormat);
+    QString cryptInfo = settings.value("DI_CRYPT_INFO").toString();
+    if (!cryptInfo.isEmpty())
+        actionKeys.insert(actionKeys.indexOf(MenuAction::Settings), MenuAction::ChangeDiskPassword);
+
     DFileMenu *menu = genereteMenuByKeys(actionKeys, disableList, false, subMenuKeys, false);
     menu->setAccessibleInfo(AC_FILE_MENU_TOOLBAR_SEETINGS);
     return menu;
@@ -227,28 +214,28 @@ DFileMenu *DFileMenuManager::createNormalMenu(const DUrl &currentUrl, const DUrl
     DUrlList redirectedUrlList;
     if (urls.length() == 1) {
         QVector<MenuAction> actions = info->menuActionList(DAbstractFileInfo::SingleFile);
-        bool isSmbSharedDir = FileUtils::isSmbShareFolder(currentUrl);
-        if (isSmbSharedDir) {
-            bool isMounted = false;
+        bool isMounted = false;
+        if (FileUtils::isSmbShareFolder(currentUrl)) {
             for (auto gvfsmp : DGioVolumeManager::getMounts()) {//遍历当前挂载
                 auto rootFile = gvfsmp->getRootFile();
                 if (!rootFile)
                     continue;
 
                 bool isSmb = FileUtils::isSmbPath(rootFile->path());
-                if(isSmb){
-                    DUrl mountUrl;
-                    QString shareName = FileUtils::smbAttribute(rootFile->path(),FileUtils::SmbAttribute::kShareName);
-                    QString shareHost = FileUtils::smbAttribute(rootFile->path(),FileUtils::SmbAttribute::kServer);
-                    QString name = currentUrl.path().toLower();//共享文件夹名称转小写
-                    QString host = currentUrl.host();
-                    if(name.startsWith("/"))
-                        name = name.mid(1);
-                    if(name == shareName && host == shareHost){
-                        isMounted =  true;
-                        break;
-                    }
+                if(!isSmb)
+                    continue;
+                DUrl mountUrl;
+                QString shareName = FileUtils::smbAttribute(rootFile->path(),FileUtils::SmbAttribute::kShareName);
+                QString shareHost = FileUtils::smbAttribute(rootFile->path(),FileUtils::SmbAttribute::kServer);
+                QString name = currentUrl.path().toLower();//共享文件夹名称转小写
+                QString host = currentUrl.host();
+                if(name.startsWith("/"))
+                    name = name.mid(1);
+                if(name == shareName && host == shareHost){
+                    isMounted =  true;
+                    break;
                 }
+
             }
             if (isMounted) {//Menu show unmount item
                 actions << MenuAction::Unmount;
@@ -922,6 +909,7 @@ void DFileMenuData::initData()
     actionKeys[MenuAction::Vault] = QObject::tr("File Vault");
     actionKeys[MenuAction::ConnectToServer] = QObject::tr("Connect to Server");
     actionKeys[MenuAction::SetUserSharePassword] = QObject::tr("Set share password");
+    actionKeys[MenuAction::ChangeDiskPassword] = QObject::tr("Change disk password");
     actionKeys[MenuAction::FormatDevice] = QObject::tr("Format");
     actionKeys[MenuAction::OpticalBlank] = QObject::tr("Erase");
 
@@ -970,9 +958,6 @@ void DFileMenuData::initData()
         actionIcons[MenuAction::Property] = QIcon::fromTheme("document-properties");
     }
 
-    // fix #bug140633,原新建文本菜单项不支持icon，与产品和UI沟通，建文本菜单项新增icon且不纳入DGioSettings
-    actionIcons[MenuAction::NewText] = QIcon::fromTheme("text-plain");
-
     actionKeys[MenuAction::RemoveStashedRemoteConn] = QObject::tr("Remove");
     actionKeys[MenuAction::UnmountAllSmbMount] = QObject::tr("Unmount");
     actionKeys[MenuAction::RefreshView] = QObject::tr("Refresh");
@@ -1359,6 +1344,7 @@ void DFileMenuManager::extensionPluginCustomMenu(DFileMenu *menu,
         return;
 
     DFMGlobal::autoInitExtPluginManager();
+    DFMExtPluginManager::instance().monitorPlugins();
 
     std::string newCurrentUrl = currentUrl.toString().toStdString();
     std::string newFocusUrl = focusFile.toString().toStdString();
@@ -1598,6 +1584,47 @@ void DFileMenuManager::resetAllActionVisibility(bool visible)
         temp->setVisible(visible);
 }
 
+void DFileMenuManager::commitReportData(QAction *action, DFileMenu *menu)
+{
+    QString appName = QApplication::applicationName();
+    if (appName != "dde-file-manager" && appName != "dde-desktop")
+        return;
+
+    QString itemName("");
+    QString location("");
+    QStringList types {};
+
+    if (action->property(DCustomActionDefines::kCustomActionFlag).isValid()) {
+        itemName = "Extended menu";
+    } else {
+        itemName = action->text();
+    }
+
+    DUrlList selected = menu->property(DCustomActionDefines::kCustomActionDataSelectedFiles).value<DUrlList>();
+    int count = selected.count();
+    if (count > 0) {
+        location = "File";
+    } else {
+        location = "Workspace";
+    }
+
+    for (int i = 0; i < count; ++i) {
+        const DUrl &u = selected.at(i);
+        DAbstractFileInfoPointer info = fileService->createFileInfo(nullptr, u);
+        if (info) {
+            QString type = info->mimeTypeName();
+            if (!types.contains(type))
+                types << type;
+        }
+    }
+
+    QVariantMap data;
+    data.insert("item_name", itemName);
+    data.insert("location", location);
+    data.insert("type", types);
+    rlog->commit("FileMenu", data);
+}
+
 void DFileMenuManager::actionTriggered(QAction *action)
 {
     qDebug() << action << action->data().isValid();
@@ -1606,6 +1633,8 @@ void DFileMenuManager::actionTriggered(QAction *action)
         disconnect(menu, &DFileMenu::triggered, fileMenuManger, &DFileMenuManager::actionTriggered);
     }
 
+    commitReportData(action, menu);
+
     //扩展菜单
     if (action->property(DCustomActionDefines::kCustomActionFlag).isValid()) {
         QString cmd = action->property(DCustomActionDefines::kCustomActionCommand).toString();
