@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     Gary Wang <wzc782970009@gmail.com>
- *
- * Maintainer: Gary Wang <wangzichong@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include <QHBoxLayout>
 #include <QPainter>
@@ -605,8 +588,11 @@ void DFMCrumbBar::onListViewContextMenu(const QPoint &point)
     menu->addAction(copyIcon, QObject::tr("Copy path"), [ = ]() {
         // 如果为保险箱路径则进行路径转换
         QString virtualUrl(url.toString());
-        if (VaultController::isVaultFile(virtualUrl))
+        if (VaultController::isVaultFile(virtualUrl)) {
             virtualUrl = VaultController::localPathToVirtualPath(url.toLocalFile());
+        } else if (url.isLocalFile()) {
+            virtualUrl = url.toLocalFile();
+        }
         QGuiApplication::clipboard()->setText(virtualUrl);
     });
 
