@@ -1,25 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     yanghao<yanghao@uniontech.com>
- *
- * Maintainer: zhengyouge<zhengyouge@uniontech.com>
- *             yanghao<yanghao@uniontech.com>
- *             hujianzhong<hujianzhong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #pragma once
 
 #include <DStandardItem>
@@ -42,6 +24,7 @@ public:
         ItemUniqueKeyRole,
         ItemVolTagRole,
         ItemSmbMountedUrls,
+        ItemReportNameRole,
         ItemUserCustomRole = Dtk::UserRole + 0x0100
     };
 
@@ -71,6 +54,7 @@ public:
     void setUrl(const DUrl &url);
     void setGroupName(const QString &groupName);
     void setRegisteredHandler(const QString &identifier);
+    void setReportName(const QString &reportName);
 
     constexpr static int SidebarItemType = QStandardItem::UserType + 1;
 
