@@ -1,26 +1,10 @@
-/*
- * Copyright (C) 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     liuzhangjian<liuzhangjian@uniontech.com>
- *
- * Maintainer: liuzhangjian<liuzhangjian@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "fulltextsearcher.h"
 #include "fulltextsearcher_p.h"
-#include "chineseanalyzer.h"
+#include "fulltext/chineseanalyzer.h"
 #include "utils/searchhelper.h"
 #include "durl.h"
 #include "dfmapplication.h"
@@ -312,7 +296,7 @@ bool FullTextSearcherPrivate::updateIndex(const QString &path)
         IndexReaderPtr reader = newIndexReader();
         IndexWriterPtr writer = newIndexWriter();
 
-        doIndexTask(reader, writer, path, kUpdate);
+        doIndexTask(reader, writer, tmpPath, kUpdate);
 
         writer->close();
         reader->close();
