@@ -1,30 +1,11 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     max-lv<lvwujun@uniontech.com>
- *
- * Maintainer: dengkeyun<dengkeyun@uniontech.com>
- *             xushitong<xushitong@uniontech.com>
- *             zhangsheng<zhangsheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
-//fixed:CD display size error
 #include "gvfs/gvfsmountmanager.h"
 
 #include "fileutils.h"
+#include "smbintegrationswitcher.h"
 
 #include "views/windowmanager.h"
 
@@ -1806,14 +1787,14 @@ bool FileUtils::writeJsonnArrayFile(const QString &filePath, const QJsonArray &a
 void FileUtils::mountAVFS()
 {
     QProcess p;
-    p.start("/usr/bin/umountavfs");
+    p.start("umountavfs", QStringList{});
     p.waitForFinished();
-    QProcess::startDetached("/usr/bin/mountavfs");
+    QProcess::startDetached("mountavfs", {});
 }
 
 void FileUtils::umountAVFS()
 {
-    QProcess::startDetached("/usr/bin/umountavfs");
+    QProcess::startDetached("umountavfs", {});
 }
 
 void FileUtils::addRecentFile(const QString &filePath, const DesktopFile &desktopFile, const QString &mimetype)
@@ -2006,6 +1987,9 @@ bool FileUtils::isSmbPath(const QString &localPath)
  */
 bool FileUtils::isSmbShareFolder(const DUrl &url)
 {
+    if(!smbIntegrationSwitcher->isIntegrationMode())
+        return false;
+
     DUrl temUrl = url;
     if(url.scheme() == DFMROOT_SCHEME){
         QString urlString = url.toString();
@@ -2013,10 +1997,10 @@ bool FileUtils::isSmbShareFolder(const DUrl &url)
         temUrl = DUrl(urlString);
     }
     QString path = temUrl.path();
-    if(path.endsWith('/') || path.endsWith('\\')){
+    if(path.endsWith('/') || path.endsWith('\\'))
         path.chop(1);
-    }
-    bool result = temUrl.scheme() == SMB_SCHEME && !path.isEmpty() && path.startsWith('/') && path.count("/") == 1;
+
+    bool result = temUrl.scheme() == SMB_SCHEME && path.startsWith('/') && path.count("/") == 1;
     return result;
 }
 
@@ -2062,6 +2046,7 @@ bool FileUtils::isSmbRelatedUrl(const DUrl &url, QString &host)
 
 /**
  * @brief FileUtils::isSmbHostOnly 判断url格式是否为smb://host或者smb://domain格式
+ *
  * @param url
  * @return
  */
@@ -2313,6 +2298,30 @@ QList<QStringList> FileUtils::catFstabFileInfo(const QString &grepData)
     return listMountInfo;
 }
 
+bool FileUtils::isArchiveByMimetype(const QString &mimetype)
+{
+    return mimeTypeDisplayManager->supportArchiveMimetypes().contains(mimetype);
+}
+
+int FileUtils::maxLabelLengthOfFileSystem(const QString &fs)
+{
+    const static QMap<QString, int> limits {
+        {"vfat", 11},   // man 8 mkfs.fat
+        {"ext2", 16},   // man 8 mke2fs
+        {"ext3", 16},   // man 8 mke2fs
+        {"ext4", 16},   // man 8 mke2fs
+        {"btrfs", 255}, // https://btrfs.wiki.kernel.org/index.php/Manpage/btrfs-filesystem
+        {"f2fs", 512},  // https://www.kernel.org/doc/Documentation/filesystems/f2fs.txt    https://git.kernel.org/pub/scm/linux/kernel/git/jaegeuk/f2fs-tools.git/tree/mkfs/f2fs_format_main.c
+        {"jfs", 16},    // jfsutils/mkfs/mkfs.c:730
+        {"exfat", 15},  // man 8 mkexfatfs
+        {"nilfs2", 80}, // man 8 mkfs.nilfs2
+        {"ntfs", 32},   // https://docs.microsoft.com/en-us/dotnet/api/system.io.driveinfo.volumelabel?view=netframework-4.8
+        {"reiserfs", 15},// man 8 mkreiserfs said its max length is 16, but after tested, only 15 chars are accepted.
+        {"xfs", 12}     // https://github.com/edward6/reiser4progs/blob/master/include/reiser4/types.h fs_hint_t
+    };
+    return limits.value(fs, 11);
+}
+
 //优化苹果文件不卡显示，存在判断错误的可能，只能临时优化，需系统提升ios传输效率
 bool FileUtils::isDesktopFile(const QString &filePath)
 {
