@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2019 Deepin Technology Co., Ltd.
- *
- * Author:     Mike Chen <kegechen@gmail.com>
- *
- * Maintainer: Mike Chen <chenke_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "dfmtagwidget.h"
 #include "dfileservices.h"
 #include "app/define.h"
@@ -176,12 +160,16 @@ void DFMTagWidget::initConnection()
         return;
 
     QObject::connect(d->m_tagCrumbEdit, &DCrumbEdit::crumbListChanged, d->m_tagCrumbEdit, [ = ]() {
-        if (!d->m_tagCrumbEdit->isEditing() && !d->m_tagCrumbEdit->property("LoadFileTags").toBool()) {
-            bool ret = DFileService::instance()->makeTagsOfFiles(nullptr, {d->m_url}, d->m_tagCrumbEdit->crumbList());
+        if (!d->m_tagCrumbEdit->property("updateCrumbsColor").toBool()) {
+            updateCrumbsColor(tagsColor(d->m_tagCrumbEdit->crumbList()));
 
-            if (!ret) {
-                loadTags(d->m_url);
-                return;
+            if (!d->m_tagCrumbEdit->isEditing() && !d->m_tagCrumbEdit->property("LoadFileTags").toBool()) {
+                bool ret = DFileService::instance()->makeTagsOfFiles(nullptr, {d->m_url}, d->m_tagCrumbEdit->crumbList());
+
+                if (!ret) {
+                    loadTags(d->m_url);
+                    return;
+                }
             }
         }
     });
@@ -214,6 +202,55 @@ void DFMTagWidget::initConnection()
     });
 }
 
+void DFMTagWidget::updateCrumbsColor(const QMap<QString, QColor> &tagsColor)
+{
+    Q_D(DFMTagWidget);
+
+    if (tagsColor.isEmpty())
+        return;
+
+    d->m_tagCrumbEdit->setProperty("updateCrumbsColor", true);
+    d->m_tagCrumbEdit->clear();
+
+    for (auto it = tagsColor.begin(); it != tagsColor.end(); ++it) {
+        DCrumbTextFormat format = d->m_tagCrumbEdit->makeTextFormat();
+        format.setText(it.key());
+
+        format.setBackground(QBrush(it.value()));
+        format.setBackgroundRadius(5);
+
+        d->m_tagCrumbEdit->insertCrumb(format, 0);
+    }
+
+    d->m_tagCrumbEdit->setProperty("updateCrumbsColor", false);
+}
+
+QMap<QString, QColor> DFMTagWidget::tagsColor(const QStringList &tagList)
+{
+    const auto &allTags = TagManager::instance()->getAllTags();
+    QMap<QString, QColor> tagsMap;
+
+    for (const auto &tag : tagList) {
+        const auto &tagMap = TagManager::instance()->getTagColor({ tag });
+        if (tagMap.isEmpty()) {
+            QColor tagColor;
+            if (allTags.contains(tag)) {
+                tagColor = allTags[tag];
+            } else {
+                const auto &colorName = TagManager::instance()->randomColor();
+                tagColor = TagManager::instance()->getColorByColorName(colorName);
+                TagManager::instance()->registerTagColor(tag, colorName);
+            }
+
+            tagsMap[tag] = tagColor;
+        } else {
+            tagsMap.unite(tagMap);
+        }
+    }
+
+    return tagsMap;
+}
+
 void DFMTagWidget::loadTags(const DUrl &durl)
 {
     Q_D(DFMTagWidget);
