@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     luzhen<luzhen@uniontech.com>
- *
- * Maintainer: zhengyouge<zhengyouge@uniontech.com>
- *             luzhen<luzhen@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
-
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "dfmvaultremovepages.h"
 #include "vault/interfaceactivevault.h"
@@ -33,6 +14,8 @@
 #include "dfmvaultremovebyrecoverykeyview.h"
 #include "accessibility/ac-lib-file-manager.h"
 #include "vaulthelper.h"
+#include "rlog/rlog.h"
+#include "rlog/datas/vaultreportdata.h"
 
 #include <DLabel>
 #include <QFrame>
@@ -311,6 +294,10 @@ void DFMVaultRemovePages::onLockVault(int state)
 void DFMVaultRemovePages::onVualtRemoveFinish(bool result)
 {
     if (result) {
+        // 上报保险箱删除成功日志
+        QVariantMap data;
+        data.insert("mode", VaultReportData::Deleted);
+        rlog->commit("Vault", data);
         setInfo(tr("Deleted successfully"));
     } else {
         setInfo(tr("Failed to delete"));
