@@ -1,14 +1,12 @@
-/**
- * Copyright (C) 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
- **/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef FILEDIALOGSTATUSBAR_H
 #define FILEDIALOGSTATUSBAR_H
 
+#include <dtkwidget_global.h>
+
 #include <QFrame>
 
 QT_BEGIN_NAMESPACE
@@ -19,6 +17,10 @@ class QComboBox;
 class QPushButton;
 QT_END_NAMESPACE
 
+DWIDGET_BEGIN_NAMESPACE
+class DSuggestButton;
+DWIDGET_END_NAMESPACE
+
 class FileDialogStatusBar : public QFrame
 {
     Q_OBJECT
@@ -38,7 +40,7 @@ public:
 
     QLineEdit *lineEdit() const;
 
-    QPushButton *acceptButton() const;
+    Dtk::Widget::DSuggestButton *acceptButton() const;
     QPushButton *rejectButton() const;
 
     void addLineEdit(QLabel *label, QLineEdit *edit);
@@ -71,7 +73,7 @@ private:
     QLineEdit *m_fileNameEdit;
     QComboBox *m_filtersComboBox;
 
-    QPushButton *m_acceptButton;
+    DTK_WIDGET_NAMESPACE::DSuggestButton *m_acceptButton;
     QPushButton *m_rejectButton;
 
     QList<QPair<QLabel *, QLineEdit *>> m_customLineEditList;
