@@ -1,24 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     lixiang<lixianga@uniontech.com>
- *
- * Maintainer: zhengyouge<zhengyouge@uniontech.com>
- *             lixiang<lixianga@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef PDFWIDGET_H
 #define PDFWIDGET_H
@@ -81,13 +63,14 @@ protected:
 private:
 
     void renderBorder(QImage &img);
+    QPixmap renderRadius(const QImage &img,int radius);
     void emptyBorder(QImage &img);
 
     void loadPageAsync(const int &index);
     void loadThumbAsync(const int &index);
     void initEmptyPages();
 
-    void resizeCurrentPage();
+    int resizeCurrentPage();
 
     QSharedPointer<PdfWidgetPrivate> d_ptr;
     QFuture<void> threadPage;
