@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     yanghao<yanghao@uniontech.com>
- *
- * Maintainer: zhengyouge<zhengyouge@uniontech.com>
- *             yanghao<yanghao@uniontech.com>
- *             hujianzhong<hujianzhong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include <signal.h>
 
@@ -50,6 +31,7 @@
 #include "accessible/accessiblelist.h"
 #include "dfmapplication.h"
 #include "views/dfilemanagerwindow.h"
+#include "rlog/rlog.h"
 
 #include <QApplication>
 #include <QDebug>
@@ -284,6 +266,10 @@ int main(int argc, char *argv[])
     }
 
     if (isSingleInstance) {
+        qInfo() << "RLog init start!";
+        rlog->init();
+        qInfo() << "RLog init finished!";
+
         // init app
         Q_UNUSED(FileManagerApp::instance())
 
